Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2998)

Unified Diff: chrome_frame/test/perf/chrome_frame_perftest.cc

Issue 3137040: GTTF: Extract performance-testing-specific parts of UITestBase to UIPerfTest.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/ui/v8_benchmark_uitest.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome_frame/test/perf/chrome_frame_perftest.cc
===================================================================
--- chrome_frame/test/perf/chrome_frame_perftest.cc (revision 57402)
+++ chrome_frame/test/perf/chrome_frame_perftest.cc (working copy)
@@ -30,7 +30,7 @@
#include "chrome/common/chrome_paths.h"
#include "chrome/common/chrome_paths_internal.h"
#include "chrome/test/chrome_process_util.h"
-#include "chrome/test/ui/ui_test.h"
+#include "chrome/test/ui/ui_perf_test.h"
#include "chrome_frame/test_utils.h"
#include "chrome_frame/utils.h"
@@ -275,7 +275,7 @@
// This class provides common functionality which can be used for most of the
// ChromeFrame/Tab performance tests.
-class ChromeFramePerfTestBase : public UITest {
+class ChromeFramePerfTestBase : public UIPerfTest {
public:
ChromeFramePerfTestBase() {}
protected:
@@ -1312,8 +1312,8 @@
base::StringPiece event_end_;
};
// The very same as UITestBase::PrintResultXXXX without the need to
// create an UITestBase instance.
void PrintResultsImpl(const std::string& measurement,
const std::string& modifier,
const std::string& trace,
@@ -1312,8 +1312,8 @@
base::StringPiece event_end_;
};
-// The very same as UITestBase::PrintResultXXXX without the need to
-// create an UITestBase instance.
+// The very same as UIPerfTest::PrintResultXXXX without the need to
+// create an UIPerfTest instance.
void PrintResultsImpl(const std::string& measurement,
const std::string& modifier,
« no previous file with comments | « chrome/test/ui/v8_benchmark_uitest.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698